==> spip_4.0.4.orig.tar.xz: plugins-dist/dump/lang/dump_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=tr
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Veritabanının geri yüklenmesi',

	// I
	'info_restauration_sauvegarde' => '@archive@ yedeğinin geri yüklenmesi',
	'info_sauvegarde' => 'Yedekle',
	'info_sauvegarde_reussi_02' => 'Veritabanı ecrire/data/@archive@ de yedeklendi. Yönetime',
	'info_sauvegarde_reussi_03' => 'geri dönebilirsiniz',
	'info_sauvegarde_reussi_04' => '.',

	// T
	'texte_admin_tech_01' => 'Bu seçenek, veritabanının içeriğini, @dossier@ dizininde depolanacak bir dosyaya yedeklemenizi sağlar. Makale ve bölümlerde kullanılan resim ve dokümanları içeren @img@ dizininin tamamını almayı da unutmayınız. ',
	'texte_admin_tech_02' => 'Dikkat : bu yedekleme ANCAK, SPIP’in aynı sürümüyle kurulacak bir sitede eski haline getirilebilir. Dolayısıyla, sakın yedekleneni güncelleme işleminden sonra yeniden kurmayı umarak  « veritabanının boşaltılması » işlemini yapmayınız...  <a href="@spipnet@">SPIP dokümanlarına</a> başvurunuz.', # MODIF
	'texte_restaurer_base' => 'Veritabanı yedeğini geri yükle',
	'texte_restaurer_sauvegarde' => 'Bu seçenek, daha önce yapılan bir veritabanı yedeğinin geri yüklenmesini sağlar. Bunun için, yedeklemeyi içeren dosyanın @dossier@ dizinine yerleştirilmiş olması gerekir. Bu işlevi kullanırken dikkatli olunuz : <b>değişiklikler, olası kayıplar, geri getirilemez.</b>', # MODIF
	'texte_sauvegarde' => 'Veritabanının içeriğini yedekle',
	'texte_sauvegarde_base' => 'Veritabanını yedekle'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_tr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=tr
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Veritabanının geri yüklenmesi',

	// I
	'info_restauration_sauvegarde' => '@archive@ yedeğinin geri yüklenmesi',
	'info_sauvegarde' => 'Yedekle',
	'info_sauvegarde_reussi_02' => 'Veritabanı ecrire/data/@archive@ de yedeklendi. Yönetime',
	'info_sauvegarde_reussi_03' => 'geri dönebilirsiniz',
	'info_sauvegarde_reussi_04' => '.',

	// T
	'texte_admin_tech_01' => 'Bu seçenek, veritabanının içeriğini, @dossier@ dizininde depolanacak bir dosyaya yedeklemenizi sağlar. Makale ve bölümlerde kullanılan resim ve dokümanları içeren @img@ dizininin tamamını almayı da unutmayınız. ',
	'texte_admin_tech_02' => 'Dikkat : bu yedekleme ANCAK, SPIP’in aynı sürümüyle kurulacak bir sitede eski haline getirilebilir. Dolayısıyla, sakın yedekleneni güncelleme işleminden sonra yeniden kurmayı umarak  « veritabanının boşaltılması » işlemini yapmayınız...  <a href="@spipnet@">SPIP dokümanlarına</a> başvurunuz.', # MODIF
	'texte_restaurer_base' => 'Veritabanı yedeğini geri yükle',
	'texte_restaurer_sauvegarde' => 'Bu seçenek, daha önce yapılan bir veritabanı yedeğinin geri yüklenmesini sağlar. Bunun için, yedeklemeyi içeren dosyanın @dossier@ dizinine yerleştirilmiş olması gerekir. Bu işlevi kullanırken dikkatli olunuz : <b>değişiklikler, olası kayıplar, geri getirilemez.</b>', # MODIF
	'texte_sauvegarde' => 'Veritabanının içeriğini yedekle',
	'texte_sauvegarde_base' => 'Veritabanını yedekle',
];
